@@ -44,6 +44,10 @@ class GlobalLabelParameters:
     PRODUCTION_URL = "api.cybersource.com"
     SANBOX_RUN_ENVIRONMENT = "CyberSource.Environment.SANDBOX"
     PRODUCTION_RUN_ENVIRONMENT = "CyberSource.Environment.PRODUCTION"
+    BOA_SANDBOX_URL = "apitest.merchant-services.bankofamerica.com"
+    BOA_PRODUCTION_URL = "api.merchant-services.bankofamerica.com"
+    BOA_SANDBOX_RUN_ENVIRONMENT = "BankofAmerica.Environment.SANDBOX"
+    BOA_PRODUCTION_RUN_ENVIRONMENT = "BankofAmerica.Environment.PRODUCTION"
     HIDE_MERCHANT_CONFIG_PROPS = "merchantid,merchant_secretkey,merchant_keyid,key_alias,key_password"
     PROXY_PREFIX = "https"
     FILE_NOT_FOUND = "File not found, Re-Enter path/file name, Entered path/file name :: "
